/******************************************************************************************
Description: 	Stored Process to refresh forecast studio projects.

Creation Date: 	04-Apr-2011

Input parameters : 1. userName - Name of the user who initiates the process

******************************************************************************************/

/*option mprint mlogic symbolgen;*/

 %macro ddcf_refresh_fsproject;

%global projectId fsproj_refresh_status job_rc project_nm plan_id ;

/*Assign transaction server library*/
%ddcf_assign_trans_library(libref=uiart);


 /* Define connection string for transactional server*/
%ddcf_connect_to_trans_db;

%let fsproj_refresh_status=0;
%let job_rc = 0;


/* Get the FS projects to be refreshed */

proc sql;
	create table FS_PROJ_OPERATION as select * 
	from uiart.FS_PROJ_OPERATION
	where OPER_CD=0 and KUPCASE(KTRIM(KLEFT(USER_NM)))=KUPCASE(KTRIM(KLEFT("&userName.")));
quit;

proc sql;
	select count(*) into :ref_rec_cnt from FS_PROJ_OPERATION ;
quit;


%if &ref_rec_cnt. > 0 %then %do;

	/* Set the status as 2 - i.e. refreshing for the project		*/

	PROC SQL noprint;
		update uiart.FS_PROJ_ANALYZE 
		set PROJECT_STATUS = 2 
		where project_id  in 
		(
		select project_id from uiart.FS_PROJ_OPERATION
		where FS_PROJ_ANALYZE.project_id = FS_PROJ_OPERATION.project_id
		and FS_PROJ_OPERATION.OPER_CD=0 
		and FS_PROJ_OPERATION.USER_NM="&userName." 	
		);
	quit;

	%do cnt= 1 %to &ref_rec_cnt.;

		%let fsproj_refresh_status=0;

		data _null_;
		obsnum=input(strip(&cnt),12.);
		set FS_PROJ_OPERATION point=obsnum;
			call symputx('projectId', project_id);
		stop;
		run;


		proc sql noprint;
		delete from uiart.fs_proj_operation where project_id = &projectId.;
		quit;

		/* Drop existing tables */
		%ddcf_set_rc(&sqlrc);

		proc sql;
			drop table scratch.FS_PROJ_MODEL_DTLS&projectId.;
		quit;

		%ddcf_set_rc(&sqlrc);

		proc sql;
			drop table scratch.FS_MDL_RSLT_SUMMARY&projectId.;
		quit;

		%ddcf_set_rc(&sqlrc);

		proc sql;
			drop table scratch.FS_MDL_RSLT_EVENT_SUMMARY&projectId.;
		quit;

		%ddcf_set_rc(&sqlrc);

		proc sql;
			drop table scratch.FS_MDL_RSLT_IV_SUMMARY&projectId.;
		quit;

		%ddcf_set_rc(&sqlrc);
/***************************Need Not be deleted *******************************/
/*		proc sql;*/
/*			drop table scratch.FS_Mixed_Hier&projectId.;*/
/*		quit;*/
/**/
/*		%ddcf_set_rc(&sqlrc);*/
/**/
/*		proc sql;*/
/*			drop table scratch.Fs_mixed_dim_hierarchy&projectId.;*/
/*		quit;*/
/*		%ddcf_set_rc(&sqlrc);*/
/********************************************************************************/


		proc sql;
			drop table scratch.Fs_hpf_mape&projectId.;
		quit;
		%ddcf_set_rc(&sqlrc);


/*******************************************************************************/


			/* Drop the UIART tables */

		proc sql;
			drop table uiartsas.FS_PROJ_MODEL_DTLS&projectId.;
		quit;

		%ddcf_set_rc(&sqlrc);


		proc sql;
			drop table uiartsas.FS_MDL_RSLT_SUMMARY&projectId.;
		quit;

		%ddcf_set_rc(&sqlrc);

		proc sql;
			drop table uiartsas.FS_MDL_RSLT_EVENT_SUMMARY&projectId.;
		quit;

		%ddcf_set_rc(&sqlrc);

		proc sql;
			drop table uiartsas.FS_MDL_RSLT_IV_SUMMARY&projectId.;
		quit;

		%ddcf_set_rc(&sqlrc);

/***************************Need Not be deleted *******************************/

/*			proc sql;*/
/*				drop table uiart.FS_MIXED_DIM_HIERARCHY&projectId.;*/
/*			quit;*/
/**/
/*			%ddcf_set_rc(&sqlrc);*/
/******************************************** *******************************/

			%if &job_rc <= 4 %then %do;

				data _null_;
				set uiart.fs_proj_analyze;
				where project_id = input("&projectId.",best12.);
				call symputx('project_nm',project_nm);
				call symputx('plan_id',plan_id);
				run;


				%ddcf_uiart_get_fs_proj_dtls;
/*				%ddcf_uiart_fs_mixed_dim_hier;*/
				%ddcf_uiart_fs_mixed_dim_mape;
				%ddcf_uiart_fs_mix_dim_sel_ind;
				%ddcf_upd_fsmixed_dimhier_sertype;

				%ddcf_uiart_fs_proj_model_dtls;
				%ddcf_uiart_fs_rslt_summary;

				%ddcf_uiart_fs_event_summ;
/**/
			/*			Creating empty structures - if required for UI - TBD later after Ittr 3 */
/*				%ddcf_create_fs_mdl_event_summ(library=UIART ,tabname=FS_MDL_RSLT_EVENT_SUMMARY&project_id.);*/

				

				data plan_indep_var; 
					set uiart.plan_indep_var;
					where plan_id=input("&plan_id.",best12.);
				run;

				proc sql noprint;
					select count(*) into :indep_actnum from plan_indep_var where adj_flg=0;
				quit;

			%if &indep_actnum. > 0 %then %do;
				%ddcf_uiart_fs_rslt_iv_summ;
			%end;
			%else %do;
				%ddcf_create_fs_mdl_iv_summ(library=uiartsas ,tabname=FS_MDL_RSLT_IV_SUMMARY&project_id.);
			%end;

				%let tableExist = %sysfunc(exist(uiartsas.FS_MDL_RSLT_SUMMARY&projectId., DATA));
				%put exist = &tableExist.;
				%if (&tableExist. eq 1) %then %do;
					proc sql;
					select count(*) into :compl from uiartsas.FS_MDL_RSLT_SUMMARY&projectId. where PREDICTED_DEMAND NE . or ACTUAL_DEMAND NE .;
						%if &compl. >0 %then %do ;
							update uiart.FS_PROJ_ANALYZE set PROJECT_STATUS = 1 where project_id = &projectId.;
						%end;
						%else %do;
							%let fsproj_refresh_status = 1;
						%end;
					quit;
				%end;
				%else %do;
					%let fsproj_refresh_status = 1;
				%end;
			%end;


		%if ( &fsproj_refresh_status. = 1  or &job_rc gt 4  ) %then %do;

			/*	Set the status as "Refresh Error"	*/

			proc sql;
				update uiart.FS_PROJ_ANALYZE set PROJECT_STATUS = 6 where project_id = &projectId.;
			quit;
		%end;
		%else %do;
			/*	Set the status as "Created"	*/
			proc sql;
				update uiart.FS_PROJ_ANALYZE set PROJECT_STATUS = 1 where project_id = &projectId.;
			quit;
		%end;

	%end; /* End of Do loop */
%end;  /* End of %if &ref_rec_cnt. condition */
%ddcf_updt_model_mgmt_filter(plan_id=&project_id, fs=1) ;
proc sql noprint;
		select count(*) into: fs_series_count from uiartsas.fs_mixed_dim_hierarchy&PROJECT_ID.; 
quit;
%put &fs_series_count.;
proc sql noprint;
	update uiart.FS_PROJ_ANALYZE 
	set no_of_series = &fs_series_count.
	where PROJECT_ID= &PROJECT_ID.
	; 
quit; 

%if &GL_FAW_POSTGRES_IND.= 1 %then %do;
	libname uiart clear;
%end;

%mend;
%ddcf_refresh_fsproject;
